==> haskell-hslua-module-text-0.1.2.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-text
version: 0.1.2.1
id: hslua-module-text-0.1.2.1-Lon3kC5i3lPDfyDlBLfC8W
key: hslua-module-text-0.1.2.1-Lon3kC5i3lPDfyDlBLfC8W
license: MIT
copyright: © 2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-test
synopsis: Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.
category: Foreign
abi: e5f2a89070002cddd4481de804864d50
exposed: True
exposed-modules:
    Foreign.Lua.Module.Text
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hslua-module-text-0.1.2.1
hs-libraries: HShslua-module-text-0.1.2.1-Lon3kC5i3lPDfyDlBLfC8W
depends:
    base-4.11.1.0 hslua-0.9.5.2-Ji0CxwvCgqDBBmJY1zwjPb text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             hslua-0.9.5.2-Ji0CxwvCgqDBBmJY1zwjPb=1fffdf1ef1e030764f04007020a0f829
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-0.1.2.1-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-text
version: 0.1.2.1
id: hslua-module-text-0.1.2.1-3XEO7MXahinDUS79JcosoX
key: hslua-module-text-0.1.2.1-3XEO7MXahinDUS79JcosoX
license: MIT
copyright: © 2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-test
synopsis: Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.
category: Foreign
abi: 68da957899eb42b6d48dcb090549e04c
exposed: True
exposed-modules:
    Foreign.Lua.Module.Text
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hslua-module-text-0.1.2.1
hs-libraries: HShslua-module-text-0.1.2.1-3XEO7MXahinDUS79JcosoX
depends:
    base-4.11.1.0 hslua-0.9.5.2-4xxJSRTPcFMCOHLtwQazz9 text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             hslua-0.9.5.2-4xxJSRTPcFMCOHLtwQazz9=2ef3938fa87973dda2fa8d5249229b63
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
